errorList property
A list containing one object for each document that contained an error. The
results are sorted in ascending order by the Index field and
match the order of the documents in the input list. If there are no errors
in the batch, the ErrorList is empty.
Implementation
final List<BatchItemError> errorList;