BatchDetectSyntaxItemResult class

The result of calling the operation. The operation returns one object that is successfully processed by the operation.

Constructors

BatchDetectSyntaxItemResult({int? index, List<SyntaxToken>? syntaxTokens})
BatchDetectSyntaxItemResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int?
The zero-based index of the document in the input list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syntaxTokens → List<SyntaxToken>?
The syntax tokens for the words in the document, one token for each word.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited