resultList property
A list of objects containing the results of the operation. The results are
sorted in ascending order by the Index field and match the
order of the documents in the input list. If all of the documents contain an
error, the ResultList is empty.
Implementation
final List<BatchDetectSyntaxItemResult> resultList;