BatchItemError class

Describes an error that occurred while processing a document in a batch. The operation returns on BatchItemError object for each document that contained an error.

Constructors

BatchItemError({String? errorCode, String? errorMessage, int? index})
BatchItemError.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode → String?
The numeric error code of the error.
final
errorMessage → String?
A text description of the error.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int?
The zero-based index of the document in the input list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited