batchDetectSentiment method
Future<BatchDetectSentimentResponse>
batchDetectSentiment({
- required LanguageCode languageCode,
- required List<
String> textList,
Inspects a batch of documents and returns an inference of the prevailing
sentiment, POSITIVE, NEUTRAL,
MIXED, or NEGATIVE, in each one.
May throw InvalidRequestException. May throw TextSizeLimitExceededException. May throw UnsupportedLanguageException. May throw BatchSizeLimitExceededException. May throw InternalServerException.
Parameter languageCode :
The language of the input documents. You can specify any of the primary
languages supported by Amazon Comprehend. All documents must be in the
same language.
Parameter textList :
A list containing the text of the input documents. The list can contain a
maximum of 25 documents. Each document must contain fewer that 5,000 bytes
of UTF-8 encoded characters.
Implementation
Future<BatchDetectSentimentResponse> batchDetectSentiment({
required LanguageCode languageCode,
required List<String> textList,
}) async {
ArgumentError.checkNotNull(languageCode, 'languageCode');
ArgumentError.checkNotNull(textList, 'textList');
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'Comprehend_20171127.BatchDetectSentiment'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'LanguageCode': languageCode.toValue(),
'TextList': textList,
},
);
return BatchDetectSentimentResponse.fromJson(jsonResponse.body);
}