DetectSentimentResponse class

Constructors

DetectSentimentResponse({SentimentType? sentiment, SentimentScore? sentimentScore})
DetectSentimentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentiment → SentimentType?
The inferred sentiment that Amazon Comprehend has the highest level of confidence in.
final
sentimentScore → SentimentScore?
An object that lists the sentiments, and their corresponding confidence levels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited