DocumentClassificationJobProperties class

Provides information about a document classification job.

Constructors

DocumentClassificationJobProperties({String? dataAccessRoleArn, String? documentClassifierArn, DateTime? endTime, InputDataConfig? inputDataConfig, String? jobId, String? jobName, JobStatus? jobStatus, String? message, OutputDataConfig? outputDataConfig, DateTime? submitTime, String? volumeKmsKeyId, VpcConfig? vpcConfig})
DocumentClassificationJobProperties.fromJson(Map<String, dynamic> json)
factory

Properties

dataAccessRoleArn → String?
The Amazon Resource Name (ARN) of the AWS identity and Access Management (IAM) role that grants Amazon Comprehend read access to your input data.
final
documentClassifierArn → String?
The Amazon Resource Name (ARN) that identifies the document classifier.
final
endTime → DateTime?
The time that the document classification job completed.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataConfig → InputDataConfig?
The input data configuration that you supplied when you created the document classification job.
final
jobId → String?
The identifier assigned to the document classification job.
final
jobName → String?
The name that you assigned to the document classification job.
final
jobStatus → JobStatus?
The current status of the document classification job. If the status is FAILED, the Message field shows the reason for the failure.
final
message → String?
A description of the status of the job.
final
outputDataConfig → OutputDataConfig?
The output data configuration that you supplied when you created the document classification job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
submitTime → DateTime?
The time that the document classification job was submitted for processing.
final
volumeKmsKeyId → String?
ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:
final
vpcConfig → VpcConfig?
Configuration parameters for a private Virtual Private Cloud (VPC) containing the resources you are using for your document classification job. For more information, see Amazon VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited