DocumentClassifierInputDataConfig class

The input properties for training a document classifier.

For more information on how the input file is formatted, see how-document-classification-training-data.

Constructors

DocumentClassifierInputDataConfig({List<AugmentedManifestsListItem>? augmentedManifests, DocumentClassifierDataFormat? dataFormat, String? labelDelimiter, String? s3Uri})
DocumentClassifierInputDataConfig.fromJson(Map<String, dynamic> json)
factory

Properties

augmentedManifests → List<AugmentedManifestsListItem>?
A list of augmented manifest files that provide training data for your custom model. An augmented manifest file is a labeled dataset that is produced by Amazon SageMaker Ground Truth.
final
dataFormat → DocumentClassifierDataFormat?
The format of your training data:
final
hashCode → int
The hash code for this object.
no setterinherited
labelDelimiter → String?
Indicates the delimiter used to separate each label for training a multi-label classifier. The default delimiter between labels is a pipe (|). You can use a different character as a delimiter (if it's an allowed character) by specifying it under Delimiter for labels. If the training documents use a delimiter other than the default or the delimiter you specify, the labels on that line will be combined to make a single unique label, such as LABELLABELLABEL.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Uri → String?
The Amazon S3 URI for the input data. The S3 bucket must be in the same region as the API endpoint that you are calling. The URI can point to a single input file or it can provide the prefix for a collection of input files.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited