dataFormat property
The format of your training data:
-
COMPREHEND_CSV: A two-column CSV file, where labels are provided in the first column, and documents are provided in the second. If you use this value, you must provide theS3Uriparameter in your request. -
AUGMENTED_MANIFEST: A labeled dataset that is produced by Amazon SageMaker Ground Truth. This file is in JSON lines format. Each line is a complete JSON object that contains a training document and its associated labels.If you use this value, you must provide the
AugmentedManifestsparameter in your request.
COMPREHEND_CSV as the default.
Implementation
final DocumentClassifierDataFormat? dataFormat;