DominantLanguage class

Returns the code for the dominant language in the input text and the level of confidence that Amazon Comprehend has in the accuracy of the detection.

Constructors

DominantLanguage({String? languageCode, double? score})
DominantLanguage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode → String?
The RFC 5646 language code for the dominant language. For more information about RFC 5646, see Tags for Identifying Languages on the IETF Tools web site.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double?
The level of confidence that Amazon Comprehend has in the accuracy of the detection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited