EndpointFilter class

The filter used to determine which endpoints are returned. You can filter jobs on their name, model, status, or the date and time that they were created. You can only set one filter at a time.

Constructors

EndpointFilter({DateTime? creationTimeAfter, DateTime? creationTimeBefore, String? modelArn, EndpointStatus? status})

Properties

creationTimeAfter → DateTime?
Specifies a date after which the returned endpoint or endpoints were created.
final
creationTimeBefore → DateTime?
Specifies a date before which the returned endpoint or endpoints were created.
final
hashCode → int
The hash code for this object.
no setterinherited
modelArn → String?
The Amazon Resource Number (ARN) of the model to which the endpoint is attached.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → EndpointStatus?
Specifies the status of the endpoint being returned. Possible values are: Creating, Ready, Updating, Deleting, Failed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited