EntitiesDetectionJobProperties class

Provides information about an entities detection job.

Constructors

EntitiesDetectionJobProperties({String? dataAccessRoleArn, DateTime? endTime, String? entityRecognizerArn, InputDataConfig? inputDataConfig, String? jobId, String? jobName, JobStatus? jobStatus, LanguageCode? languageCode, String? message, OutputDataConfig? outputDataConfig, DateTime? submitTime, String? volumeKmsKeyId, VpcConfig? vpcConfig})
EntitiesDetectionJobProperties.fromJson(Map<String, dynamic> json)
factory

Properties

dataAccessRoleArn → String?
The Amazon Resource Name (ARN) that gives Amazon Comprehend read access to your input data.
final
endTime → DateTime?
The time that the entities detection job completed
final
entityRecognizerArn → String?
The Amazon Resource Name (ARN) that identifies the entity recognizer.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataConfig → InputDataConfig?
The input data configuration that you supplied when you created the entities detection job.
final
jobId → String?
The identifier assigned to the entities detection job.
final
jobName → String?
The name that you assigned the entities detection job.
final
jobStatus → JobStatus?
The current status of the entities detection job. If the status is FAILED, the Message field shows the reason for the failure.
final
languageCode → LanguageCode?
The language code of the input documents.
final
message → String?
A description of the status of a job.
final
outputDataConfig → OutputDataConfig?
The output data configuration that you supplied when you created the entities detection job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
submitTime → DateTime?
The time that the entities detection job was submitted for processing.
final
volumeKmsKeyId → String?
ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:
final
vpcConfig → VpcConfig?
Configuration parameters for a private Virtual Private Cloud (VPC) containing the resources you are using for your entity detection job. For more information, see Amazon VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited