EntityRecognizerInputDataConfig class

Specifies the format and location of the input data.

Properties

annotations → EntityRecognizerAnnotations?
The S3 location of the CSV file that annotates your training documents.
final
augmentedManifests → List<AugmentedManifestsListItem>?
A list of augmented manifest files that provide training data for your custom model. An augmented manifest file is a labeled dataset that is produced by Amazon SageMaker Ground Truth.
final
dataFormat → EntityRecognizerDataFormat?
The format of your training data:
final
documents → EntityRecognizerDocuments?
The S3 location of the folder that contains the training documents for your custom entity recognizer.
final
entityList → EntityRecognizerEntityList?
The S3 location of the CSV file that has the entity list for your custom entity recognizer.
final
entityTypes → List<EntityTypesListItem>
The entity types in the labeled training data that Amazon Comprehend uses to train the custom entity recognizer. Any entity types that you don't specify are ignored.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited