EntityRecognizerMetadata class

Detailed information about an entity recognizer.

Constructors

EntityRecognizerMetadata({List<EntityRecognizerMetadataEntityTypesListItem>? entityTypes, EntityRecognizerEvaluationMetrics? evaluationMetrics, int? numberOfTestDocuments, int? numberOfTrainedDocuments})
EntityRecognizerMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

entityTypes → List<EntityRecognizerMetadataEntityTypesListItem>?
Entity types from the metadata of an entity recognizer.
final
evaluationMetrics → EntityRecognizerEvaluationMetrics?
Detailed information about the accuracy of an entity recognizer.
final
hashCode → int
The hash code for this object.
no setterinherited
numberOfTestDocuments → int?
The number of documents in the input data that were used to test the entity recognizer. Typically this is 10 to 20 percent of the input documents.
final
numberOfTrainedDocuments → int?
The number of documents in the input data that were used to train the entity recognizer. Typically this is 80 to 90 percent of the input documents.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited