EntityRecognizerProperties class

Describes information about an entity recognizer.

Constructors

EntityRecognizerProperties({String? dataAccessRoleArn, DateTime? endTime, String? entityRecognizerArn, EntityRecognizerInputDataConfig? inputDataConfig, LanguageCode? languageCode, String? message, EntityRecognizerMetadata? recognizerMetadata, ModelStatus? status, DateTime? submitTime, DateTime? trainingEndTime, DateTime? trainingStartTime, String? volumeKmsKeyId, VpcConfig? vpcConfig})
EntityRecognizerProperties.fromJson(Map<String, dynamic> json)
factory

Properties

dataAccessRoleArn → String?
The Amazon Resource Name (ARN) of the AWS Identity and Management (IAM) role that grants Amazon Comprehend read access to your input data.
final
endTime → DateTime?
The time that the recognizer creation completed.
final
entityRecognizerArn → String?
The Amazon Resource Name (ARN) that identifies the entity recognizer.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataConfig → EntityRecognizerInputDataConfig?
The input data properties of an entity recognizer.
final
languageCode → LanguageCode?
The language of the input documents. All documents must be in the same language. Only English ("en") is currently supported.
final
message → String?
A description of the status of the recognizer.
final
recognizerMetadata → EntityRecognizerMetadata?
Provides information about an entity recognizer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ModelStatus?
Provides the status of the entity recognizer.
final
submitTime → DateTime?
The time that the recognizer was submitted for processing.
final
trainingEndTime → DateTime?
The time that training of the entity recognizer was completed.
final
trainingStartTime → DateTime?
The time that training of the entity recognizer started.
final
volumeKmsKeyId → String?
ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:
final
vpcConfig → VpcConfig?
Configuration parameters for a private Virtual Private Cloud (VPC) containing the resources you are using for your custom entity recognizer. For more information, see Amazon VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited