EventsDetectionJobProperties class

Provides information about an events detection job.

Constructors

EventsDetectionJobProperties({String? dataAccessRoleArn, DateTime? endTime, InputDataConfig? inputDataConfig, String? jobId, String? jobName, JobStatus? jobStatus, LanguageCode? languageCode, String? message, OutputDataConfig? outputDataConfig, DateTime? submitTime, List<String>? targetEventTypes})
EventsDetectionJobProperties.fromJson(Map<String, dynamic> json)
factory

Properties

dataAccessRoleArn → String?
The Amazon Resource Name (ARN) of the AWS Identify and Access Management (IAM) role that grants Amazon Comprehend read access to your input data.
final
endTime → DateTime?
The time that the events detection job completed.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataConfig → InputDataConfig?
The input data configuration that you supplied when you created the events detection job.
final
jobId → String?
The identifier assigned to the events detection job.
final
jobName → String?
The name you assigned the events detection job.
final
jobStatus → JobStatus?
The current status of the events detection job.
final
languageCode → LanguageCode?
The language code of the input documents.
final
message → String?
A description of the status of the events detection job.
final
outputDataConfig → OutputDataConfig?
The output data configuration that you supplied when you created the events detection job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
submitTime → DateTime?
The time that the events detection job was submitted for processing.
final
targetEventTypes → List<String>?
The types of events that are detected by the job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited