InputDataConfig class

The input properties for a topic detection job.

Constructors

InputDataConfig({required String s3Uri, InputFormat? inputFormat})
InputDataConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputFormat → InputFormat?
Specifies how the text in an input file should be processed:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Uri → String
The Amazon S3 URI for the input data. The URI must be in same region as the API endpoint that you are calling. The URI can point to a single input file or it can provide the prefix for a collection of data files.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited