KeyPhrase class

Describes a key noun phrase.

Constructors

KeyPhrase({int? beginOffset, int? endOffset, double? score, String? text})
KeyPhrase.fromJson(Map<String, dynamic> json)
factory

Properties

beginOffset → int?
A character offset in the input text that shows where the key phrase begins (the first character is at position 0). The offset returns the position of each UTF-8 code point in the string. A code point is the abstract character from a particular graphical representation. For example, a multi-byte UTF-8 character maps to a single code point.
final
endOffset → int?
A character offset in the input text where the key phrase ends. The offset returns the position of each UTF-8 code point in the string. A code point is the abstract character from a particular graphical representation. For example, a multi-byte UTF-8 character maps to a single code point.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double?
The level of confidence that Amazon Comprehend has in the accuracy of the detection.
final
text → String?
The text of a key noun phrase.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited