ListDocumentClassificationJobsResponse class

Constructors

ListDocumentClassificationJobsResponse({List<DocumentClassificationJobProperties>? documentClassificationJobPropertiesList, String? nextToken})
ListDocumentClassificationJobsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

documentClassificationJobPropertiesList → List<DocumentClassificationJobProperties>?
A list containing the properties of each job returned.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
Identifies the next page of results to return.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited