PiiOutputDataConfig class

Provides configuration parameters for the output of PII entity detection jobs.

Constructors

PiiOutputDataConfig({required String s3Uri, String? kmsKeyId})
PiiOutputDataConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt the output results from an analysis job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Uri → String
When you use the PiiOutputDataConfig object with asynchronous operations, you specify the Amazon S3 location where you want to write the output data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited