RedactionConfig class

Provides configuration parameters for PII entity redaction.

Constructors

RedactionConfig({String? maskCharacter, PiiEntitiesDetectionMaskMode? maskMode, List<PiiEntityType>? piiEntityTypes})
RedactionConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maskCharacter → String?
A character that replaces each character in the redacted PII entity.
final
maskMode → PiiEntitiesDetectionMaskMode?
Specifies whether the PII entity is redacted with the mask character or the entity type.
final
piiEntityTypes → List<PiiEntityType>?
An array of the types of PII entities that Amazon Comprehend detects in the input text for your request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited