SentimentScore class

Describes the level of confidence that Amazon Comprehend has in the accuracy of its detection of sentiments.

Constructors

SentimentScore({double? mixed, double? negative, double? neutral, double? positive})
SentimentScore.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mixed → double?
The level of confidence that Amazon Comprehend has in the accuracy of its detection of the MIXED sentiment.
final
negative → double?
The level of confidence that Amazon Comprehend has in the accuracy of its detection of the NEGATIVE sentiment.
final
neutral → double?
The level of confidence that Amazon Comprehend has in the accuracy of its detection of the NEUTRAL sentiment.
final
positive → double?
The level of confidence that Amazon Comprehend has in the accuracy of its detection of the POSITIVE sentiment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited