StartDominantLanguageDetectionJobResponse class

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobId → String?
The identifier generated for the job. To get the status of a job, use this identifier with the operation.
final
jobStatus → JobStatus?
The status of the job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited