StopEntitiesDetectionJobResponse class

Constructors

StopEntitiesDetectionJobResponse({String? jobId, JobStatus? jobStatus})
StopEntitiesDetectionJobResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobId → String?
The identifier of the entities detection job to stop.
final
jobStatus → JobStatus?
Either STOP_REQUESTED if the job is currently running, or STOPPED if the job was previously stopped with the StopEntitiesDetectionJob operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited