SyntaxToken class

Represents a work in the input text that was recognized and assigned a part of speech. There is one syntax token record for each word in the source text.

Constructors

SyntaxToken({int? beginOffset, int? endOffset, PartOfSpeechTag? partOfSpeech, String? text, int? tokenId})
SyntaxToken.fromJson(Map<String, dynamic> json)
factory

Properties

beginOffset → int?
The zero-based offset from the beginning of the source text to the first character in the word.
final
endOffset → int?
The zero-based offset from the beginning of the source text to the last character in the word.
final
hashCode → int
The hash code for this object.
no setterinherited
partOfSpeech → PartOfSpeechTag?
Provides the part of speech label and the confidence level that Amazon Comprehend has that the part of speech was correctly identified. For more information, see how-syntax.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
The word that was recognized in the source text.
final
tokenId → int?
A unique identifier for a token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited