TopicsDetectionJobProperties class

Provides information about a topic detection job.

Constructors

TopicsDetectionJobProperties({String? dataAccessRoleArn, DateTime? endTime, InputDataConfig? inputDataConfig, String? jobId, String? jobName, JobStatus? jobStatus, String? message, int? numberOfTopics, OutputDataConfig? outputDataConfig, DateTime? submitTime, String? volumeKmsKeyId, VpcConfig? vpcConfig})
TopicsDetectionJobProperties.fromJson(Map<String, dynamic> json)
factory

Properties

dataAccessRoleArn → String?
The Amazon Resource Name (ARN) of the AWS Identity and Management (IAM) role that grants Amazon Comprehend read access to your job data.
final
endTime → DateTime?
The time that the topic detection job was completed.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataConfig → InputDataConfig?
The input data configuration supplied when you created the topic detection job.
final
jobId → String?
The identifier assigned to the topic detection job.
final
jobName → String?
The name of the topic detection job.
final
jobStatus → JobStatus?
The current status of the topic detection job. If the status is Failed, the reason for the failure is shown in the Message field.
final
message → String?
A description for the status of a job.
final
numberOfTopics → int?
The number of topics to detect supplied when you created the topic detection job. The default is 10.
final
outputDataConfig → OutputDataConfig?
The output data configuration supplied when you created the topic detection job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
submitTime → DateTime?
The time that the topic detection job was submitted for processing.
final
volumeKmsKeyId → String?
ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:
final
vpcConfig → VpcConfig?
Configuration parameters for a private Virtual Private Cloud (VPC) containing the resources you are using for your topic detection job. For more information, see Amazon VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited